==> ipydagred3-0.3.7.tar.gz: ipydagred3-0.3.7/js/src/view.js <==
/* eslint-disable no-underscore-dangle */
import {DOMWidgetView} from "@jupyter-widgets/base";
import {graphlib, render} from "dagre-d3";
import * as d3 from "d3";

// Import the CSS
import "../style/index.css";

export class DagreD3View extends DOMWidgetView {
  graph;

  svg;

  inner;

  tooltip;

  renderer;

  throttle;

  queued;

  render() {
    this.model.on("msg:custom", this._handle_message, this);
    this.el.classList.add("dagred3");

    this.tooltip = document.querySelector("#dagred3tooltip");
    if (!this.tooltip) {
      this.tooltip = document.createElement("div");
      this.tooltip.id = "dagred3tooltip";
      this.tooltip.style.visibility = "hidden";
      this.tooltip.style.position = "absolute";
      this.tooltip.style.zIndex = "1000";
      document.body.appendChild(this.tooltip);
    }

    const el = d3.select(this.el);
    this.svg = el.append("svg");
    this.svg.attr("height", "600");
    this.svg.attr("width", "800");

    this.inner = this.svg.append("g");
    this.inner.attr("height", "600");
    this.inner.attr("width", "800");
    this.graph = new graphlib.Graph().setGraph({height: 400, width: 400});

    // eslint-disable-next-line new-cap
    this.renderer = new render();

    this.displayed.then(() => {
      // Set up zoom support
      const zoom = d3.zoom().on("zoom", () => {
        this.inner.attr("transform", d3.event.transform);
      });
      this.svg.call(zoom);

      // Center the graph
      const initialScale = 0.75;
      this.svg.call(zoom.transform, d3.zoomIdentity.translate((parseInt(this.svg.attr("width"), 10) - (this.graph.graph().width || 0) * initialScale) / 2, 20).scale(initialScale));

      this.svg.attr("height", (this.graph.graph().height || 0) * initialScale + 40);
      this.graph_changed();
    });
  }

  _render() {
    if (this.throttle) {
      // do not schedule a render
      // eslint-disable-next-line no-console
      console.log("[ipydagred3] throttling...");
      this.queued = true;
      return;
    }

    this.throttle = 1; // set guard

    this.renderer(this.inner, this.graph);

    const tooltip = d3.select("#dagred3tooltip");
    this.inner
      .selectAll("g.node")
      .attr("data-tooltip", (v) => this.graph.node(v).tooltip)
      .on("click", (v) => {
        this.send({event: "click", value: v});
      })
      .on("mouseover", () => tooltip.style("visibility", "visible"))
      .on("mousemove", (v) => {
        tooltip
          .text(this.graph.node(v).tooltip)
          .style("top", `${d3.event.pageY - 10}px`)
          .style("left", `${d3.event.pageX + 10}px`);
      })
      .on("mouseout", () => tooltip.style("visibility", "hidden"));

    // any queued will now have been rendered
    this.queued = false;

    // remove guard after timeout, rerender if any queue
    this.throttle = setTimeout(() => {
      // since this sets throttle, if any render
      // requests come in during the 200ms cooldown,
      // they'll set queued and a rerender will be triggered
      this.throttle = undefined;
      if (this.queued) {
        this._render();
      }
    }, 200);
  }

  _handle_message(msg) {
    if (msg.type === "setNode") {
      this.setNode(msg.source.name, msg.source.attrs);
    } else if (msg.type === "setEdge") {
      this.setEdge(msg.source.v.name, msg.source.w.name, msg.source.attrs);
    } else if (msg.type === "graph") {
      const ob = {};
      ob[msg.attr] = msg.value;
      this.graph.setGraph(ob);
    } else if (msg.type === "node") {
      this.setNode(msg.source.name, msg.source.attrs);
    } else if (msg.type === "edge") {
      this.setEdge(msg.source.v.name, msg.source.w.name, msg.source.attrs);
    }
    this._render();
  }

  setNode(name, attrs) {
    this.graph.setNode(name, attrs);
  }

  setEdge(v, w, attrs) {
    const tooltip = d3.select("#dagred3tooltip");
    const label = document.createElement("u");
    label.onmouseover = () => tooltip.style("visibility", "visible");

    label.onmouseout = () => tooltip.style("visibility", "hidden");

    label.onmousemove = (e) =>
      tooltip
        .text(attrs.tooltip)
        .style("top", `${e.pageY - 10}px`)
        .style("left", `${e.pageX + 10}px`);

    label.onclick = () => {
      this.send({event: "click", value: [v, w]});
    };

    label.innerHTML = attrs.label;
    // eslint-disable-next-line no-param-reassign
    attrs.label = label;
    // eslint-disable-next-line no-param-reassign
    attrs.labelType = "html";
    this.graph.setEdge(v, w, attrs);
  }

  graph_changed() {
    const graph = this.model.get("_graph");

    const ob = {
      compound: graph.compound,
      directed: graph.directed,
      multigraph: graph.multigraph,
    };

    this.graph.setGraph(ob);

    graph.nodes.forEach((n) => {
      this.setNode(n.name, n.attrs);
    });
    graph.edges.forEach((e) => {
      this.setEdge(e.v.name, e.w.name, e.attrs);
    });
    this._render();
  }
}

==> ipydagred3-0.3.8.tar.gz: ipydagred3-0.3.8/js/src/view.js <==
/* eslint-disable no-underscore-dangle */
import {DOMWidgetView} from "@jupyter-widgets/base";
import {graphlib, render} from "dagre-d3-es";
import * as d3 from "d3";
import throttle from "lodash/throttle";

// Import the CSS
import "../style/index.css";

export class DagreD3View extends DOMWidgetView {
  graph;

  svg;

  inner;

  tooltip;

  renderer;

  throttled_render;

  queued;

  render() {
    this.model.on("msg:custom", this._handle_message, this);
    this.el.classList.add("dagred3");

    this.tooltip = document.querySelector("#dagred3tooltip");
    if (!this.tooltip) {
      this.tooltip = document.createElement("div");
      this.tooltip.id = "dagred3tooltip";
      this.tooltip.style.visibility = "hidden";
      this.tooltip.style.position = "absolute";
      this.tooltip.style.zIndex = "1000";
      document.body.appendChild(this.tooltip);
    }

    const el = d3.select(this.el);
    this.svg = el.append("svg");

    this.inner = this.svg.append("g");
    this.graph = new graphlib.Graph();
    this.graph = new graphlib.Graph({directed: this.model.get("_graph").directed});
    this.graph.setGraph({
      nodesep: 70,
      ranksep: 50,
      marginx: 20,
      marginy: 20,
      rankdir: this.model.get("_graph").attrs.rankdir || "TB",
    });

    // set height and width
    const model_height = this.model.get("_graph").attrs.height;
    const model_width = this.model.get("_graph").attrs.width;
    if (model_height) {
      this.svg.height = model_height;
    }
    if (model_width) {
      this.svg.width = model_width;
    }

    // eslint-disable-next-line new-cap
    this.renderer = new render();

    this.throttled_render = throttle(() => this._render(), 5);

    this.displayed.then(() => {
      // Set up zoom support
      const zoom = d3.zoom().on("zoom", (event) => {
        this.inner.attr("transform", event.transform);
      });
      this.svg.call(zoom);

      // Center the graph
      const initialScale = 0.75;
      const width = this.el.offsetWidth;
      const height = this.el.offsetHeight;
      this.svg.call(
        zoom.transform,
        d3.zoomIdentity.translate((width - (this.graph.graph().width || 0) * initialScale) / 2, (height - (this.graph.graph().height || 0) * initialScale) / 2).scale(initialScale)
      );

      this.graph_changed();
    });
  }

  _render() {
    this.renderer(this.inner, this.graph);

    const tooltip = d3.select("#dagred3tooltip");
    this.inner
      .selectAll("g.node")
      // TODO commenting out for d3v5 -> d3v7 seems to have no effect ¯\_(ツ)_/¯
      // .attr("data-tooltip", (event, value) => this.graph.node(value).tooltip)
      .on("click", (event, value) => {
        this.send({event: "click", value});
      })
      .on("mouseover", () => tooltip.style("visibility", "visible"))
      .on("mousemove", (event, value) => {
        tooltip
          .text(this.graph.node(value).tooltip)
          .style("top", `${event.pageY - 10}px`)
          .style("left", `${event.pageX + 10}px`);
      })
      .on("mouseout", () => tooltip.style("visibility", "hidden"));
  }

  _handle_message(msg) {
    if (msg.type === "setNode") {
      this.setNode(msg.source.name, msg.source.attrs);
    } else if (msg.type === "setEdge") {
      this.setEdge(msg.source.v.name, msg.source.w.name, msg.source.attrs);
    } else if (msg.type === "graph") {
      const ob = {};
      ob[msg.attr] = msg.value;
      this.graph.setGraph(ob);
    } else if (msg.type === "node") {
      this.setNode(msg.source.name, msg.source.attrs);
    } else if (msg.type === "edge") {
      this.setEdge(msg.source.v.name, msg.source.w.name, msg.source.attrs);
    }
    this.throttled_render();
  }

  setNode(name, attrs) {
    this.graph.setNode(name, attrs);
  }

  setEdge(v, w, attrs) {
    const tooltip = d3.select("#dagred3tooltip");
    const label = document.createElement("u");
    label.onmouseover = () => tooltip.style("visibility", "visible");

    label.onmouseout = () => tooltip.style("visibility", "hidden");

    label.onmousemove = (e) =>
      tooltip
        .text(attrs.tooltip)
        .style("top", `${e.pageY - 10}px`)
        .style("left", `${e.pageX + 10}px`);

    label.onclick = () => {
      this.send({event: "click", value: [v, w]});
    };

    label.innerHTML = attrs.label;
    // eslint-disable-next-line no-param-reassign
    attrs.label = label;
    // eslint-disable-next-line no-param-reassign
    attrs.labelType = "html";
    this.graph.setEdge(v, w, attrs);
  }

  graph_changed() {
    const graph = this.model.get("_graph");

    const ob = {
      compound: graph.compound,
      directed: graph.directed,
      multigraph: graph.multigraph,
    };

    this.graph.setGraph(ob);

    graph.nodes.forEach((n) => {
      this.setNode(n.name, n.attrs);
    });
    graph.edges.forEach((e) => {
      this.setEdge(e.v.name, e.w.name, e.attrs);
    });
    this.throttled_render();
  }
}
